=== modified file 'NEWS'
--- NEWS	2007-05-28 02:08:25 +0000
+++ NEWS	2007-05-31 04:59:25 +0000
@@ -9,11 +9,11 @@
       revisions, instead of "merged:". (Kent Gibson)
 
     * The --lsprof-file option now dumps a text rendering of the profiling
-      information if the filename ends in "txt". It will also convert the
+      information if the filename ends in ".txt". It will also convert the
       profiling information to a format suitable for KCacheGrind if the
-      output filename ends in "grind". Fixes to the lsprofcalltree conversion
-      process by Jean Paul Calderone and Itamar were also merged. See
-      http://ddaa.net/blog/python/lsprof-calltree. (Ian Clatworthy)
+      output filename ends in ".callgrind". Fixes to the lsprofcalltree
+      conversion process by Jean Paul Calderone and Itamar were also merged.
+      See http://ddaa.net/blog/python/lsprof-calltree. (Ian Clatworthy)
 
   IMPROVEMENTS:
   

=== modified file 'bzrlib/commands.py'
--- bzrlib/commands.py	2007-05-28 02:08:25 +0000
+++ bzrlib/commands.py	2007-05-31 04:59:25 +0000
@@ -541,9 +541,9 @@
         stats.pprint()
     else:
         outfile = open(filename, 'w')
-        if filename.endswith("grind"):
+        if filename.endswith(".callgrind"):
             stats.calltree(outfile)
-        elif filename.endswith("txt"):
+        elif filename.endswith(".txt"):
             stats.pprint(file=outfile)
         else:
             stats.freeze()

=== modified file 'bzrlib/lsprof.py'
--- bzrlib/lsprof.py	2007-05-28 02:08:25 +0000
+++ bzrlib/lsprof.py	2007-05-31 04:59:25 +0000
@@ -106,6 +106,14 @@
 
 
 class _CallTreeFilter(object):
+    """Converter of a Stats object to input suitable for KCacheGrind.
+
+    This code is taken from http://ddaa.net/blog/python/lsprof-calltree
+    with the changes made by J.P. Calderone and Itamar applied. Note that
+    isinstance(code, str) needs to be used at times to determine if the code 
+    object is actually an external code object (with a filename, etc.) or
+    a Python built-in.
+    """
 
     def __init__(self, data):
         self.data = data

=== modified file 'doc/developers/HACKING'
--- doc/developers/HACKING	2007-05-28 02:08:25 +0000
+++ doc/developers/HACKING	2007-05-31 04:59:25 +0000
@@ -974,38 +974,6 @@
 by setting the environment variable ``BZR_SIGQUIT_PDB=0``.
 
 
-Profiling
-=========
-
-Bazaar has some built-in support for collecting and saving profiling
-information. In the simpliest case, the --lsprof option can be used as
-shown below::
-
-  bzr --lsprof ...
-
-This will dump the profiling information to stdout before exiting.
-Alternatively, the --lsprof-file option can be used to specify a filename
-to save the profiling data into to. By default, profiling data saved to a
-file is a pickled Python object making it possible to reload the data and
-do with it what you will. For convenience though:
-
-* if the filename ends in "txt", it will be dumped in a text format.
-
-* if the filename ends in "grind", it will be converted to a format
-  loadable by the KCacheGrind visualisation tool.
-
-Here is an example of how to use the --lsprof-file option in combination
-with KCacheGrind to visualise what the "status" command is doing::
-
-  bzr --lsprof-file status001.callgrind status
-  kcachegrind status001.callgrind &
-
-.. Note:: bzr also has a --profile option that uses the hotshot profiler
-   instead of the lsprof profiler. The hotshot profiler can be useful
-   though the lsprof one is generally recommended. See
-   http://docs.python.org/lib/node795.html.
-
-
 Jargon
 ======
 

=== modified file 'doc/developers/index.txt'
--- doc/developers/index.txt	2007-05-08 04:14:01 +0000
+++ doc/developers/index.txt	2007-05-31 04:59:25 +0000
@@ -13,3 +13,7 @@
 * `Performance roadmap <performance-roadmap.htm>`_
 
   The roadmap for fixing performance in bzr over the next few releases.
+
+* `Profiling notes <profiling.htm>`_
+
+  Instructions on how to profile bzr code and visualize the results.

=== added file 'doc/developers/profiling.txt'
--- doc/developers/profiling.txt	1970-01-01 00:00:00 +0000
+++ doc/developers/profiling.txt	2007-05-31 04:59:25 +0000
@@ -0,0 +1,32 @@
+Profiling
+=========
+
+Bazaar has some built-in support for collecting and saving profiling
+information. In the simpliest case, the --lsprof option can be used as
+shown below::
+
+  bzr --lsprof ...
+
+This will dump the profiling information to stdout before exiting.
+Alternatively, the --lsprof-file option can be used to specify a filename
+to save the profiling data into to. By default, profiling data saved to a
+file is a pickled Python object making it possible to reload the data and
+do with it what you will. For convenience though:
+
+* if the filename ends in ".txt", it will be dumped in a text format.
+
+* if the filename ends in ".callgrind", it will be converted to a format
+  loadable by the KCacheGrind visualization tool.
+
+Here is an example of how to use the --lsprof-file option in combination
+with KCacheGrind to visualize what the "status" command is doing::
+
+  bzr --lsprof-file status001.callgrind status
+  kcachegrind status001.callgrind &
+
+.. Note:: bzr also has a --profile option that uses the hotshot profiler
+   instead of the lsprof profiler. The hotshot profiler can be useful
+   though the lsprof one is generally recommended. See
+   http://docs.python.org/lib/node795.html.
+
+

